@@ -1,13 +1,11 @@
 from typing import TYPE_CHECKING
-from importlib import import_module
 from .basic import ExtendFunction
 
+# ruff: noqa F401
+
 if TYPE_CHECKING:
     from .. import ToolDelta
 
-function_modules = [
-    "gamerule_warnings",
-]
 registered_function_clss: list[type[ExtendFunction]] = []
 registered_functions: list[ExtendFunction] = []
 
@@ -17,6 +15,7 @@ def regist_extend_function(func: type[ExtendFunction]):
 
 
 def load_functions(frame: "ToolDelta"):
+    import_functions()
     for func_cls in registered_function_clss:
         func = func_cls(frame)
         registered_functions.append(func)
@@ -28,8 +27,5 @@ def activate_functions():
 
 
 def import_functions():
-    for function_module in function_modules:
-        import_module(f".{function_module}", package=__package__)
+    from . import gamerule_warnings
 
-
-import_functions()
